@@ -195,7 +195,7 @@ if __name__ == '__main__':
     ont.merge_dict(None, get_dict_from_list_without_underscore, os.path.join(PATH, "adj_pos.txt"), None)
     ont.merge_dict(None, get_dict_from_list_without_underscore, os.path.join(PATH, "adj_neg.txt"), None)
 
-    ont = Ontology(ont.lemmatize(ignore=['_positive adj','_negative adj']))
+    ont = Ontology(ont.lemmatize(ignore=['_positive adj','_negative adj','_female names', '_male names']))
 
     #ont.display()
 
