@@ -81,12 +81,25 @@ reciprocity = {
 
         '{#DISAGREE,#IDK}': {
 
-            '`I get you.`'
+            '`You don\'t? No big deal. I\'m just always looking for recommendations! `'
             '#GSRET(rexit)':
                 'rexit'
         },
 
+        '{[!i do -not],<#AGREE,#TOKLIMIT(1)>}':{
+            'state': 'user_fave_book_y',
+
+            '`I wonder if I have heard of it. What is it called?`'
+            '#GSRET(rexit)':
+             {
+                'state': 'user_fave_book_unx',
+
+                '#UNX': 'user_fave_book_reply'
+             }
+        },
+
         '#UNX':{
+            'state': 'user_fave_book_reply',
 
             '`Cool! What do you like about it?`'
             '#GATE': {
