@@ -183,7 +183,7 @@ user = {
                 }
             },
 
-            '[{#AGREE, it is}]': {
+            '{#AGREE,[it is]}': {
 
                 '`You think I wouldn\'t remember your name? Anyway,` #GRET': 'exit'
             }
