@@ -1081,4 +1081,4 @@ class DialogueFlow:
         self.reset()
         self.set_state(config['state'])
         self.set_vars(config['vars'])
-        self.set_gates(config['gates'])
+        self.set_gates(defaultdict(config['gates']))
